@@ -23,6 +23,7 @@ import osso
 import hildon
 import urllib2
 import urllib
+import httplib
 import simplejson
 import bitly
 import accountData
@@ -199,8 +200,8 @@ class account():
                     rtdata = self.api.GetRetweets_to_user()
                 else:
                     print "refreshing since" + str(self.accountdata.last_id)
-                    data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id)
-                    rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id)
+                    data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id, count=200)
+                    rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id, count=200)
             else:
                 if self.accountdata.oldest_id == None:
                     data = self.api.GetFriendsTimeline(count=get_count)
@@ -275,6 +276,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
 
     def getMentions(self, auto=0, older=False, get_count=20, * args):
@@ -374,6 +377,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
     def getDMs(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -463,7 +468,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
-
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
     def getFriends(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -518,6 +524,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
     def getPublic(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -602,6 +610,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
 
     def getUserHistory(self, friend="", auto=0, older=False, get_count=20, * args):
@@ -661,6 +671,8 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
             print msg
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
 
     def getSearch(self, searchTerms="", auto=0, older=False, get_count=20, * args):
@@ -730,6 +742,8 @@ class account():
                 if (auto == 0):
                     note = osso.SystemNote(self.osso_c)
                     note.system_note_dialog(msg)
+            except httplib.BadStatusLine:
+                print "Network error - BadStatusLine"
 
     def getTrends(self, *args):
 
@@ -767,7 +781,8 @@ class account():
                 msg = msg + 'Server returned ' + str(e.code) + " : " + reason
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog(msg)
-
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
 
 
     def get_specific_tweet(self,username,tweet_id):
